#!/usr/bin/env python2
# -*- coding: utf-8 -*-
# PYTHON_ARGCOMPLETE_OK

## Dependencies:    mplayer, argparse, argcomplete, pyYAML
## Author:          Gijs Timmers: https://github.com/GijsTimmers

## Licence:         CC-BY-SA-4.0
##                  http://creativecommons.org/licenses/by-sa/4.0/

## This work is licensed under the Creative Commons
## Attribution-ShareAlike 4.0 International License. To  view a copy of
## this license, visit http://creativecommons.org/licenses/by-sa/4.0/ or
## send a letter to Creative Commons, PO Box 1866, Mountain View,
## CA 94042, USA.

import re
import sys

class Communicator():
    def __init__(self):
        self.oudeInfo = ""
        self.BREEDTE_TERMINAL = 80
    def processChannelName(self, zender):
        print "Speelt nu af: [{zender}]".format(zender=zender)
        
        ## Huidige radiozender weergeven als terminaltitel.
        sys.stdout.write("\x1b]2;{zender}\x07".format(zender=zender))
        
    def processIcy(self, regel):
        ## Het oudeInfo/nieuweInfo-mechanisme
        ## is een mechanisme om iedere keer alleen het nieuwste ICY-bericht
        ## in het leesvenster te plaatsen.
        ## Wat uitleg over de regex:
        ## Alles tussen
        ## ICY Info: StreamTitle='
        ## en
        ## ';
        ## wordt opgeslagen als nieuweInfo. .* is non-greedy gemaakt
        ## met een vraagteken, zodat een eventueel volgende streamUrl
        ## niet wordt opgenomen in de nieuweInfo. Uiteindelijk nog een
        ## strip()-statement om losse spaties voorin en achterin de
        ## string weg te nemen.
        
        self.nieuweInfo = regel

        if self.nieuweInfo != self.oudeInfo:
            sys.stdout.write("\r" + " " * self.BREEDTE_TERMINAL)
            sys.stdout.write("\r" + "Info:         [{info}]".format(info=self.nieuweInfo))
            self.oudeInfo = self.nieuweInfo


#!/usr/bin/env python2
# -*- coding: utf-8 -*-
# PYTHON_ARGCOMPLETE_OK

## Dependencies:    mplayer, argparse, argcomplete, pyYAML
## Author:          Gijs Timmers: https://github.com/GijsTimmers

## Licence:         CC-BY-SA-4.0
##                  http://creativecommons.org/licenses/by-sa/4.0/

## This work is licensed under the Creative Commons
## Attribution-ShareAlike 4.0 International License. To  view a copy of
## this license, visit http://creativecommons.org/licenses/by-sa/4.0/ or
## send a letter to Creative Commons, PO Box 1866, Mountain View,
## CA 94042, USA.

import getch                    ## Toetsaanslagen opvangen

class Keypress():
    def __init__(self):
        KEY_ENTER  = "\r"
        KEY_Q      = "q"
        KEY_CTRL_C = "\x03"
        KEY_ESC    = "\x1b"
        
        self.EXITKEYS = set([KEY_ENTER, KEY_Q, KEY_CTRL_C, KEY_ESC])
        
    def getexitkeypress(self):
        keypress = getch.getch()
        if keypress in self.EXITKEYS:
            return True
        else:
            return False 



#!/usr/bin/env python2
# -*- coding: utf-8 -*-
# PYTHON_ARGCOMPLETE_OK

## Dependencies:    mplayer, argparse, argcomplete, pyYAML
## Author:          Gijs Timmers: https://github.com/GijsTimmers

## Licence:         CC-BY-SA-4.0
##                  http://creativecommons.org/licenses/by-sa/4.0/

## This work is licensed under the Creative Commons
## Attribution-ShareAlike 4.0 International License. To  view a copy of
## this license, visit http://creativecommons.org/licenses/by-sa/4.0/ or
## send a letter to Creative Commons, PO Box 1866, Mountain View,
## CA 94042, USA.

from .keypress import Keypress
from .fabriek import Fabriek
from .parser import Parser
from .radio import Radio

import threading                ## Voor multithreading
import cursor                   ## Cursor tonen/verbergen
import time                     ## Polling voor opvangen keypress
import sys                      ## Basislib
import re                       ## Regex

def main():
    pa = Parser()
    naam, url, comm = pa.zendervinden()
    #print naam, url, comm
    cursor.hide()
    
    fa = Fabriek()
    co = fa.returnCommunicatorObject(comm)
        
    rd = Radio()
    t = threading.Thread(target=rd.afspelen, args=(naam, url, co))
    t.start()
    
    ## Afspelen stoppen na drukken op één van de EXITKEYS
    kp = Keypress()
    while kp.getexitkeypress() == False:
        time.sleep(0.2)
    
    cursor.show()
    rd.stoppen()
    
    return 0